//**************************************************************************************************
//*  FRIDA: fast reliable interactive data analysis                          
//*  (C) Joachim Wuttke 1990-, v2(C++) 2001-                                 
//*  http://apps.jcns.fz-juelich.de/frida                                    
//**************************************************************************************************

//! \file  integrate.hpp
//! \brief NCurveIntegral: integrate a curve file

#include "registry.hpp"

//!  Function type: Evaluate curve functional

typedef void (*cvin_eval) (
    double *r, double *dr, ROlc fc, int k, int j, const vector<double>& args );


//! A wrapper holding a functional.

class CCvin {
 public:
    string name;
    int narg;
    cvin_eval eval;
    string com;
    vector<RNode> def_arg;
    class CCoord coord( class CCoord *co ) const;
    class CCoord coord( class CCoord *co1, class CCoord *co2 ) const;
    CCvin( string _name, int _narg, string _def, cvin_eval _eval, string _com="" );
    void register_me() const;
};


//! Collection of function wrappers CFunc

namespace NCvin { // public (short) interface
    void set_integration_tuning_pars( string which );
}

class SCvinRegistry : public IRegistry<CCvin>, public triv::ISingleton<SCvinRegistry> {
 private:
    virtual string type_name() const { return "curve functionals"; }
 public:
    void display_entries() const;
    static void initialize();
};

