//**************************************************************************************************
//*  FRIDA: fast reliable interactive data analysis
//*  (C) Joachim Wuttke 1990-, v2(C++) 2001-
//*  http://apps.jcns.fz-juelich.de/frida
//**************************************************************************************************

//! \file  reg.cpp
//! \brief Implements class SVariRegistry.

#include "defs.hpp"
#include "ptr.hpp"
#include "variables.hpp"


PObj SVariRegistry::find( string key ) const
{
    auto pos = Map.find(key);
    return pos == Map.end() ? nullptr : pos->second;
}

PObj SVariRegistry::find_or_fail( string key ) const
{
    PObj ret = find( key );
    if( !ret )
        throw "Cannot find genusiable '" + key + "'";
    return ret;
}


void SVariRegistry::display_functions() const
{
    /*
    // this implementation works only, if flist is strictly ordered:
    // first operators by precedence, then functions.

    cout << "Operators by precedence:\n";
    int precedence = -1;
    for( int i=0; i<FList.size(); ++i ){
        const CFunc *f;
        f = FList[i];
        if( f->precedence ) { // operators
            if( f->precedence!=precedence )
                cout << "\n ";
            cout << " " << f->key;
        } else { // functions
            if( f->precedence!=precedence )
                cout << "\nBuilt-in functions:\n";
            cout << "  " << f->key << f->explanation << "\n";
            }
        precedence = f->precedence;
    }
    */
}

void SVariRegistry::register_scalar( string key, PObj val )
{
    Map[key] = val;
}

//! Undefines a key (removes entry from registry); returns true unless the key wasn't defined.

bool SVariRegistry::undef( string key )
{
    auto pos = Map.find(key);
    if( pos==Map.end() )
        return false; // failure
    Map.erase( pos );
    return true;
}
